import pytest
from django.contrib.auth.models import User
from django.test import RequestFactory, TestCase
from django.urls import reverse

from adminfilters.filters import TextFieldFilter, ForeignKeyFieldFilter
from demoproject.demoapp.models import DemoModelField, DemoRelated, DemoModel

DATA = {
    "nullable": "bbbb",
    "float": 10.1,
    "generic_ip": "192.168.10.2",
    "url": "https://github.com/saxix/django-adminfilters",
    "decimal": "22.2",
    "time": "19:00:35",
    "blank": "",
    "datetime": "2013-01-01T02:18:33Z",
    "not_editable": None,
    "bigint": 333333333,
    "text": "lorem ipsum",
    "null_logic": True,
    "logic": False,
    "date": "2013-01-29",
    "integer": 888888,
    "email": "s.apostolico@gmail.com",
    "choices": 2
}


@pytest.fixture
def fixtures(db):
    obj1 = DemoModelField.objects.create(char="a1", unique=1, **DATA)
    related = DemoRelated.objects.create(name='related1')
    DemoModel.objects.create(demo_related=related, name='name1')
    return DemoModelField.objects.create(char="a2", unique=2, **DATA)


def test_TextFieldFilter(fixtures, rf):
    f = TextFieldFilter.factory('char')

    qs = f(None, {'char|iexact': 'www'}, None, None).queryset(None, DemoModelField.objects.all())
    assert not qs.exists()

    qs = f(None, {'char|iexact': 'a1'}, None, None).queryset(None, DemoModelField.objects.all())
    assert qs.exists()


def test_ForeignKeyFieldFilter(fixtures, rf):
    f = ForeignKeyFieldFilter.factory('demo_related__name__istartswith')

    qs = f(None, {'demo_related|name|istartswith': 'www'}, None, None).queryset(None, DemoModel.objects.all())
    assert not qs.exists()

    qs = f(None, {'demo_related|name|istartswith': 'related1'}, None, None).queryset(None, DemoModel.objects.all())
    assert qs.exists()



from django.contrib.admin.filters import (AllValuesFieldListFilter,
                                          RelatedFieldListFilter,
                                          SimpleListFilter, )
from django.db.models.query_utils import Q
from django.utils.encoding import smart_str
from django.utils.translation import ugettext as _

from django.db.models.fields.related import ForeignObjectRel


def get_attr(obj, attr, default=None):
    """Recursive get object's attribute. May use dot notation.

    """
    if '.' not in attr:
        return getattr(obj, attr, default)
    else:
        L = attr.split('.')
        return get_attr(getattr(obj, L[0], default), '.'.join(L[1:]), default)


class AllValuesComboFilter(AllValuesFieldListFilter):
    template = 'adminfilters/combobox.html'


class AllValuesRadioFilter(AllValuesFieldListFilter):
    template = 'adminfilters/fieldradio.html'


class RelatedFieldComboFilter(RelatedFieldListFilter):
    template = 'adminfilters/fieldcombobox.html'


class RelatedFieldRadioFilter(RelatedFieldListFilter):
    template = 'adminfilters/fieldradio.html'


class RelatedFieldCheckBoxFilter(RelatedFieldListFilter):
    template = 'adminfilters/fieldcheckbox.html'

    def __init__(self, field, request, params, model, model_admin, field_path):
        self.model_admin = model_admin
        super(RelatedFieldCheckBoxFilter, self).__init__(field, request, params, model, model_admin, field_path)
        self.lookup_val = request.GET.getlist(self.lookup_kwarg, [])

    def queryset(self, request, queryset):
        filters = Q()

        for val in self.lookup_val:
            filters.add(Q(**{self.lookup_kwarg: val}), Q.OR)

        if (self.lookup_val_isnull):
            filters.add(Q(**{self.lookup_kwarg_isnull: self.lookup_val_isnull}), Q.OR)

        return queryset.filter(filters)

    def choices(self, cl):
        try:
            from django.contrib.admin.views.main import EMPTY_CHANGELIST_VALUE
        except ImportError:
            EMPTY_CHANGELIST_VALUE = self.model_admin.get_empty_value_display()

        uncheck_all = []
        uncheck_all.append("{}={}".format(self.lookup_kwarg_isnull, 1))
        for i in self.lookup_choices:
            uncheck_all.append("{}={}".format(self.lookup_kwarg, i[0]))

        yield {
            'selected': not len(self.lookup_val) and not self.lookup_val_isnull,
            'query_string': cl.get_query_string({}, [self.lookup_kwarg, self.lookup_kwarg_isnull]),
            'display': _('All'),
            'check_to_remove': "&".join(uncheck_all)

        }
        yield {
            'selected': self.lookup_val_isnull,
            'query_string': cl.get_query_string({self.lookup_kwarg_isnull: 1},
                                                [self.lookup_kwarg, self.lookup_kwarg_isnull]),
            'display': _('None'),
            'uncheck_to_remove': "{}=1".format(self.lookup_kwarg_isnull)
        }
        for pk_val, val in self.lookup_choices:
            yield {
                'selected': smart_str(pk_val) in self.lookup_val,
                'query_string': cl.get_query_string(
                    {
                        self.lookup_kwarg: pk_val,
                    },
                    [self.lookup_kwarg_isnull]),
                'display': val,
                'uncheck_to_remove': "{}={}".format(self.lookup_kwarg, pk_val) if pk_val else ""
            }
        if (isinstance(self.field, ForeignObjectRel)
                and self.field.field.null
                or hasattr(self.field, 'rel') and self.field.null):
            yield {
                'selected': bool(self.lookup_val_isnull),
                'query_string': cl.get_query_string(
                    {
                        self.lookup_kwarg_isnull: 'True',
                    },
                    [self.lookup_kwarg]),
                'uncheck_to_remove': "{}=1".format(self.lookup_kwarg_isnull),
                'display': EMPTY_CHANGELIST_VALUE,
            }


class TextFieldFilter(SimpleListFilter):
    template = 'adminfilters/text.html'

    prefixes = None
    # lookup_val = 'field|filter'
    parameter_name = None

    @classmethod
    def factory(cls, lookup, title=None):
        if title is None:
            title = lookup.replace('__', ', ')
        parts = lookup.split('__')
        if len(parts) == 1:
            lookup = '%s__iexact' % parts[0]
        # elif len(parts) > 2:
        #     raise Exception(
        #         "lookup must contains at least two parts. ForeignKey|Field|Filter (groups|name|istartswith)")

        return type('TextFieldFilter',
                    (cls,), {'parameter_name': lookup.replace('__', '|'),
                             'title': title})

    @property
    def title(self):
        # getattr(field, 'verbose_name', field_path)
        return '--'

    def has_output(self):
        return True

    def value(self):
        return self.used_parameters.get(self.parameter_name, '')

    def queryset(self, request, queryset):
        if self.value():
            field = self.parameter_name.replace('|', '__')
            return queryset.filter(**{field: self.value()})
        return queryset

    def lookups(self, request, model_admin):
        return []

    def choices(self, changelist):
        yield {
            'selected': False,
            'query_string': changelist.get_query_string(
                {},
                [self.parameter_name, ]
            ),
            'lookup_kwarg': self.parameter_name,
            'display': _('All'),
            'value': self.value(),
        }


class PermissionPrefixFilter(SimpleListFilter):
    title = 'Permission'
    parameter_name = 'perm'
    prefixes = (('add', 'Add'), ('change', 'Change'), ('delete', 'Delete'), ('--', 'Others'))
    lookup_val = None

    def lookups(self, request, model_admin):
        return self.prefixes

    def queryset(self, request, queryset):
        if not self.value():
            return queryset
        if self.value() == '--':
            k = [prefix for prefix, label in self.prefixes]
            query = Q()
            for el in k:
                query |= Q(codename__startswith=el)
            return queryset.exclude(query)
        else:
            return queryset.filter(codename__startswith=self.value())


ForeignKeyFieldFilter = TextFieldFilter



from django.contrib.admin.filters import FieldListFilter
from django.db.models.fields import AutoField, IntegerField
from django.utils.translation import ugettext_lazy as _


class MultipleSelectFieldListFilter(FieldListFilter):

    def __init__(self, field, request, params, model, model_admin, field_path):
        self.lookup_kwarg = '%s_filter' % field_path
        self.filter_statement = '%s' % field_path
        self.lookup_val = request.GET.get(self.lookup_kwarg, None)
        self.lookup_choices = field.get_choices(include_blank=False)
        super(MultipleSelectFieldListFilter, self).__init__(
            field, request, params, model, model_admin, field_path)

    def expected_parameters(self):
        return [self.lookup_kwarg]

    def get_field(self):
        try:
            field = self.field.remote_field.model._meta.pk
        except AttributeError:  # django < 2.0
            field = self.field.rel.to._meta.pk
        return field

    def values(self):
        """
        Returns a list of values to filter on.
        """
        values = []
        value = self.used_parameters.get(self.lookup_kwarg, None)
        if value:
            values = value.split(',')

        field = self.get_field()
        # convert to integers if IntegerField
        if type(field) in [IntegerField, AutoField]:
            values = [int(x) for x in values]
        return values

    def queryset(self, request, queryset):
        raise NotImplementedError

    def choices(self, cl):
        # from django.contrib.admin.views.main import EMPTY_CHANGELIST_VALUE
        yield {
            'selected': self.lookup_val is None,
            'query_string': cl.get_query_string(
                {},
                [self.lookup_kwarg]),
            'display': _('All')
        }
        for pk_val, val in self.lookup_choices:
            selected = pk_val in self.values()
            pk_list = set(self.values())
            if selected:
                pk_list.remove(pk_val)
            else:
                pk_list.add(pk_val)
            queryset_value = ','.join([str(x) for x in pk_list])
            if pk_list:
                query_string = cl.get_query_string(
                    {
                        self.lookup_kwarg: queryset_value,
                    })
            else:
                query_string = cl.get_query_string({}, [self.lookup_kwarg])
            yield {
                'selected': selected,
                'query_string': query_string,
                'display': val,
            }


class IntersectionFieldListFilter(MultipleSelectFieldListFilter):
    """
    A FieldListFilter which allows multiple selection of
    filters for many-to-many type fields. A list of objects will be
    returned whose m2m contains all the selected filters.
    """

    def queryset(self, request, queryset):
        for value in self.values():
            filter_dct = {
                self.filter_statement: value
            }
            queryset = queryset.filter(**filter_dct)
        return queryset


class UnionFieldListFilter(MultipleSelectFieldListFilter):
    """
    A FieldListFilter which allows multiple selection of
    filters for many-to-many type fields, or any type with choices.
    A list of objects will be returned whose m2m or value set
    contains one of the selected filters.
    """

    def get_field(self):
        try:
            field = super(UnionFieldListFilter, self).get_field()
        except AttributeError:
            if hasattr(self.field, "choices") and self.field.choices:
                field = self.field  # It's a *Field with choises
            else:
                raise AttributeError(
                    'Multiselect field must be a FK or any type with choices')
        return field

    def queryset(self, request, queryset):
        filter_statement = "%s__in" % self.filter_statement
        filter_values = self.values()
        filter_dct = {
            filter_statement: filter_values
        }
        if filter_values:
            return queryset.filter(**filter_dct)
        else:
            return queryset



from django.contrib.admin import ModelAdmin
from django.contrib.auth.admin import UserAdmin

from adminfilters.filters import (ForeignKeyFieldFilter,
                                  RelatedFieldCheckBoxFilter,
                                  RelatedFieldRadioFilter, TextFieldFilter, )
from adminfilters.multiselect import (IntersectionFieldListFilter,
                                      UnionFieldListFilter,)

from .models import DemoModel, DemoRelated


class DemoModelAdmin_RelatedFieldCheckBoxFilter(ModelAdmin):
    list_display = [f.name for f in DemoModel._meta.fields]
    list_filter = (('demo_related', RelatedFieldCheckBoxFilter),
                   ForeignKeyFieldFilter.factory('demo_related__name__icontains'),
                   TextFieldFilter.factory('name'),
                   )


class DemoModelAdmin_RelatedFieldRadioFilter(ModelAdmin):
    list_display = [f.name for f in DemoModel._meta.fields]
    list_filter = (('demo_related', RelatedFieldRadioFilter),)


class DemoModelAdmin_UnionFieldListFilter(ModelAdmin):
    list_display = [f.name for f in DemoModel._meta.fields]
    list_filter = (('demo_related', UnionFieldListFilter),)


class DemoModelAdmin_IntersectionFieldListFilter(ModelAdmin):
    list_display = [f.name for f in DemoModel._meta.fields]
    list_filter = (('demo_related', IntersectionFieldListFilter),)


class DemoModelModelAdmin(ModelAdmin):
    list_display = [f.name for f in DemoModel._meta.fields]
    list_filter = (
        ForeignKeyFieldFilter.factory('demo_related__name__istartswith'),
        TextFieldFilter.factory('name'),
    )


class DemoRelatedModelAdmin(ModelAdmin):
    list_display = [f.name for f in DemoRelated._meta.fields]


class IUserAdmin(UserAdmin):
    list_display = ('username', 'email', 'first_name', 'last_name',
                    'is_staff')
    list_filter = TextFieldFilter.factory('username__istartswith'),



from django.conf import settings
from django.contrib.auth.backends import ModelBackend
from django.contrib.auth.models import Permission


class AnyUserBackend(ModelBackend):
    supports_object_permissions = False
    supports_anonymous_user = True

    def get_all_permissions(self, user_obj, obj=None):
        if settings.DEBUG:
            return Permission.objects.all().values_list('content_type__app_label', 'codename').order_by()
        return super(AnyUserBackend, self).get_all_permissions(user_obj, obj)

    def get_group_permissions(self, user_obj, obj=None):
        if settings.DEBUG:
            return Permission.objects.all().values_list('content_type__app_label', 'codename').order_by()
        return super(AnyUserBackend, self).get_group_permissions(user_obj, obj)

    def has_perm(self, user_obj, perm, obj=None):
        if settings.DEBUG:
            return True
        return super(AnyUserBackend, self).has_perm(user_obj, perm, obj)

    def has_module_perms(self, user_obj, app_label):
        if settings.DEBUG:
            return True
        return super(AnyUserBackend, self).has_module_perms(user_obj, app_label)



# Generated by Django 2.0.2 on 2018-02-21 16:38

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DemoModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='DemoModelField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('char', models.CharField(max_length=255)),
                ('integer', models.IntegerField()),
                ('logic', models.BooleanField(default=False)),
                ('null_logic', models.NullBooleanField(default=None)),
                ('date', models.DateField()),
                ('datetime', models.DateTimeField()),
                ('time', models.TimeField()),
                ('decimal', models.DecimalField(decimal_places=3, max_digits=10)),
                ('email', models.EmailField(max_length=254)),
                ('float', models.FloatField()),
                ('bigint', models.BigIntegerField()),
                ('generic_ip', models.GenericIPAddressField()),
                ('url', models.URLField()),
                ('text', models.TextField()),
                ('unique', models.CharField(max_length=255, unique=True)),
                ('nullable', models.CharField(max_length=255, null=True)),
                ('blank', models.CharField(blank=True, max_length=255, null=True)),
                ('not_editable', models.CharField(blank=True, editable=False, max_length=255, null=True)),
                ('choices', models.IntegerField(choices=[(1, 'Choice 1'), (2, 'Choice 2'), (3, 'Choice 3')])),
            ],
        ),
        migrations.CreateModel(
            name='DemoRelated',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.AddField(
            model_name='demomodel',
            name='demo_related',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='demoapp.DemoRelated'),
        ),
        migrations.CreateModel(
            name='DemoModel_IntersectionFieldListFilter',
            fields=[
            ],
            options={
                'verbose_name': 'IntersectionFieldListFilter',
                'proxy': True,
                'indexes': [],
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_RelatedFieldCheckBoxFilter',
            fields=[
            ],
            options={
                'verbose_name': 'RelatedFieldCheckBoxFilter',
                'proxy': True,
                'indexes': [],
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_RelatedFieldRadioFilter',
            fields=[
            ],
            options={
                'verbose_name': 'RelatedFieldRadioFilter',
                'proxy': True,
                'indexes': [],
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_UnionFieldListFilter',
            fields=[
            ],
            options={
                'verbose_name': 'UnionFieldListFilter',
                'proxy': True,
                'indexes': [],
            },
            bases=('demoapp.demomodel',),
        ),
    ]



from django.db import models


class DemoModelField(models.Model):
    char = models.CharField(max_length=255)
    integer = models.IntegerField()
    logic = models.BooleanField(default=False)
    null_logic = models.NullBooleanField(default=None)
    date = models.DateField()
    datetime = models.DateTimeField()
    time = models.TimeField()
    decimal = models.DecimalField(max_digits=10, decimal_places=3)
    email = models.EmailField()
    #    filepath = models.FilePathField(path=__file__)
    float = models.FloatField()
    bigint = models.BigIntegerField()
    generic_ip = models.GenericIPAddressField()
    url = models.URLField()
    text = models.TextField()

    unique = models.CharField(max_length=255, unique=True)
    nullable = models.CharField(max_length=255, null=True)
    blank = models.CharField(max_length=255, blank=True, null=True)
    not_editable = models.CharField(max_length=255, editable=False,
                                    blank=True, null=True)
    choices = models.IntegerField(choices=((1, 'Choice 1'),
                                           (2, 'Choice 2'),
                                           (3, 'Choice 3')))

    class Meta:
        app_label = 'demoapp'


class DemoRelated(models.Model):
    name = models.CharField(max_length=255)

    def __unicode__(self):
        return self.name


class DemoModel(models.Model):
    name = models.CharField(max_length=255)
    demo_related = models.ForeignKey('DemoRelated',
                                     verbose_name='Demo Related',
                                     on_delete=models.CASCADE)

    class Meta:
        app_label = 'demoapp'


class DemoModel_RelatedFieldCheckBoxFilter(DemoModel):

    class Meta:
        proxy = True
        verbose_name = "RelatedFieldCheckBoxFilter"


class DemoModel_RelatedFieldRadioFilter(DemoModel):

    class Meta:
        proxy = True
        verbose_name = "RelatedFieldRadioFilter"


class DemoModel_UnionFieldListFilter(DemoModel):

    class Meta:
        proxy = True
        verbose_name = "UnionFieldListFilter"


class DemoModel_IntersectionFieldListFilter(DemoModel):

    class Meta:
        proxy = True
        verbose_name = "IntersectionFieldListFilter"



import django.contrib.admin
import django.contrib.admin.sites
from django.conf.urls import url
from django.contrib.auth.models import User

from .demoapp import admin, models


class PublicAdminSite(django.contrib.admin.sites.AdminSite):

    def has_permission(self, request):
        request.user = User.objects.get_or_create(username='sax')[0]
        return True


public_site = PublicAdminSite()
django.contrib.admin.autodiscover()
public_site.register(models.DemoModel_RelatedFieldCheckBoxFilter,
                     admin.DemoModelAdmin_RelatedFieldCheckBoxFilter)
public_site.register(models.DemoModel_RelatedFieldRadioFilter,
                     admin.DemoModelAdmin_RelatedFieldRadioFilter)
public_site.register(models.DemoModel_UnionFieldListFilter,
                     admin.DemoModelAdmin_UnionFieldListFilter)
public_site.register(models.DemoModel_IntersectionFieldListFilter,
                     admin.DemoModelAdmin_IntersectionFieldListFilter)
public_site.register(models.DemoRelated, admin.DemoRelatedModelAdmin)
public_site.register(models.DemoModel, admin.DemoModelModelAdmin)
public_site.register(User, admin.IUserAdmin)

urlpatterns = (
    url(r'', public_site.urls),
    # url(r'^admin/', include(public_site.urls)),
)



from django.contrib.auth.models import User
from django.test import RequestFactory, TestCase
from django.urls import reverse


class AdminFilterTests(TestCase):
    fixtures = ['demoproject']

    def setUp(self):
                # Every test needs access to the request factory.
        self.factory = RequestFactory()
        self.user = User.objects.create_user(
            username='sax', email='sax@sax.com', password='top_secret')
        self.user.is_superuser = True
        self.user.save()

    def test_admin_filter_RelatedFieldRadioFilter(self):
        """
        test if the admin page with RelatedFieldRadioFilter filters loads succesfully
        """
        self.assertTrue(self.client.login(
            username='sax', password='top_secret'))
        response = self.client.get(
            reverse('admin:demoapp_demomodel_relatedfieldradiofilter_changelist'))
        self.assertEqual(response.status_code, 200)
        response = self.client.get(reverse(
            'admin:demoapp_demomodel_relatedfieldradiofilter_changelist') + "?demo_related__id__exact=1")
        self.assertEqual(response.status_code, 200)
        response = self.client.get(reverse('admin:demoapp_demomodel_relatedfieldradiofilter_changelist') +
                                   "?demo_related__id__exact=1&demo_related__id__exact=2")
        self.assertEqual(response.status_code, 200)

    def test_admin_RelatedFieldCheckbox(self):
        """
        test if the admin page with RelatedFieldCheckbox filters loads succesfully
        """
        self.assertTrue(self.client.login(
            username='sax', password='top_secret'))
        response = self.client.get(
            reverse('admin:demoapp_demomodel_relatedfieldcheckboxfilter_changelist'))
        self.assertEqual(response.status_code, 200)
        response = self.client.get(reverse(
            'admin:demoapp_demomodel_relatedfieldcheckboxfilter_changelist') + "?demo_related__id__exact=1")
        self.assertEqual(response.status_code, 200)

    def test_admin_UnionFieldListFilter(self):
        """
        test if the admin page with UnionFieldListFilter filters loads succesfully
        """
        self.assertTrue(self.client.login(
            username='sax', password='top_secret'))
        response = self.client.get(
            reverse('admin:demoapp_demomodel_unionfieldlistfilter_changelist'))
        self.assertEqual(response.status_code, 200)
        response = self.client.get(reverse(
            'admin:demoapp_demomodel_unionfieldlistfilter_changelist') + "?demo_related_filter=1%2C2")
        self.assertEqual(response.status_code, 200)

    def test_admin_IntersectionFieldListFilter(self):
        """
        test if the admin page with IntersectionFieldListFilter filter loads succesfully
        """
        self.assertTrue(self.client.login(
            username='sax', password='top_secret'))
        response = self.client.get(
            reverse('admin:demoapp_demomodel_intersectionfieldlistfilter_changelist'))
        self.assertEqual(response.status_code, 200)
        response = self.client.get(reverse(
            'admin:demoapp_demomodel_intersectionfieldlistfilter_changelist') + "?demo_related_filter=1%2C2")
        self.assertEqual(response.status_code, 200)


    def test_admin_TextFieldFilter(self):
        """
        test if the admin page with IntersectionFieldListFilter filter loads succesfully
        """
        self.assertTrue(self.client.login(
            username='sax', password='top_secret'))
        response = self.client.get(
            reverse('admin:demoapp_demomodel_intersectionfieldlistfilter_changelist'))
        self.assertEqual(response.status_code, 200)
        response = self.client.get(reverse(
            'admin:demoapp_demomodel_intersectionfieldlistfilter_changelist') + "?name=ccccc")
        self.assertEqual(response.status_code, 200)



#!/usr/bin/env python
import ast
import codecs
import os

import re
from setuptools import find_packages, setup

ROOT = os.path.realpath(os.path.join(os.path.dirname(__file__)))
init = os.path.join(ROOT, 'src', 'adminfilters', '__init__.py')

_version_re = re.compile(r'__version__\s+=\s+(.*)')
_name_re = re.compile(r'NAME\s+=\s+(.*)')

with open(init, 'rb') as f:
    content = f.read().decode('utf-8')
    version = str(ast.literal_eval(_version_re.search(content).group(1)))
    name = str(ast.literal_eval(_name_re.search(content).group(1)))


def read(*parts):
    here = os.path.abspath(os.path.dirname(__file__))
    return codecs.open(os.path.join(here, 'src', 'requirements', *parts), "r").read()


install_requires = read('install.pip')
tests_requires = read('testing.pip')
dev_requires = tests_requires + read('develop.pip')

setup(name=name,
      version=version,
      url='https://github.com/saxix/django-adminfilters',
      download_url='https://github.com/saxix/django-adminfilters',
      author='sax',
      author_email='sax@os4d.org',
      description="Extra filters for django admin site",
      license='MIT',
      package_dir={'': 'src'},
      packages=find_packages('src'),
      include_package_data=True,
      extras_require={
          'test': tests_requires,
          'dev': dev_requires
      },
      platforms=['any'],
      classifiers=[
          'Environment :: Web Environment',
          'Framework :: Django',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          'Intended Audience :: Developers'],
      long_description=codecs.open('README.rst', 'r').read()
      )
